import { Construct } from "constructs";
import { Secret } from "./Config.js";
/**
 * SST Auth is a lightweight authentication solution for your applications. With a simple set of configuration you can deploy a function attached to your API that can handle various authentication flows.  *
 * @example
 * ```ts
 * import { Auth } from "@serverless-stack/resources"
 *
 * new Auth(stack, "auth", {
 *   api: myApi,
 *   function: "functions/auth.handler",
 *   prefix: "/auth" // optional
 * })
 */
export class Auth extends Construct {
    constructor(scope, id, props) {
        super(scope, id);
        this.SST_AUTH_TOKEN = new Secret(scope, "SST_AUTH_TOKEN");
        const prefix = props.prefix || "/auth";
        const path = `ANY ${prefix}/{proxy+}`;
        props.api.addRoutes(scope, {
            [path]: {
                type: "function",
                function: props.authenticator,
            },
        });
        props.api.getFunction(path).addConfig([this.SST_AUTH_TOKEN]);
        for (const route of props.api.routes) {
            const func = props.api.getFunction(route);
            if (!func)
                continue;
            func.addConfig([this.SST_AUTH_TOKEN]);
        }
    }
}
